onReconnect property
Called after a successful reconnection so the consumer can re-authenticate and re-subscribe to collections.
Implementation
Future<void> Function()? onReconnect;
Called after a successful reconnection so the consumer can re-authenticate and re-subscribe to collections.
Future<void> Function()? onReconnect;