ReconnectionStrategy class
Calculates reconnection delays using exponential backoff with optional jitter.
Call delayFor to get the delay for the current attempt, then increment to advance to the next attempt. Call reset when a connection is successfully established.
Constructors
- ReconnectionStrategy(RetryPattern params)
Properties
Methods
-
delayFor(
) → Duration -
increment(
{int amount = 1}) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- defaultStrategy → ReconnectionStrategy
-
no setter